@@ -164,7 +164,7 @@ gkm_main_ui_init (GKMMainUI *self)
   default_keyring = 
     gkm_keyring_manager_get_default_keyring (GKM_KEYRING_MANAGER (self->priv->manager));
 
-  self->priv->editor = gkm_keyring_editor_new ("default");
+  self->priv->editor = gkm_keyring_editor_new (NULL);
   tree_model = gkm_keyring_editor_get_model (GKM_KEYRING_EDITOR (self->priv->editor));
   gtk_tree_view_set_model (GTK_TREE_VIEW (self->priv->keys_treeview), 
 			   tree_model);
@@ -789,7 +789,7 @@ on_about_activate (GtkWidget *widget G_GNUC_UNUSED,
 {
   g_return_if_fail (GKM_IS_MAIN_UI (self));
 
-  gkm_application_open_about_dialog (GTK_WINDOW (self->priv->window));
+  gkm_show_about_dialog (GTK_WINDOW (self->priv->window));
 }
 
 /* End of help menu functions */
@@ -892,6 +892,25 @@ on_keyrings_treeview_selection_changed (GtkTreeSelection *selection,
   }
 }
 
+static void
+on_keyrings_model_row_changed (GtkTreeModel *model,
+			       GtkTreePath  *path G_GNUC_UNUSED,
+			       GtkTreeIter  *iter,
+			       GKMMainUI    *self)
+{
+  if (gkm_keyring_editor_get_keyring_name (GKM_KEYRING_EDITOR (self->priv->editor)) == NULL)
+    {
+      gchar *keyring_name;
+      
+      gtk_tree_model_get (model, iter, 
+			  MANAGER_COLUMN_KEYRING, &keyring_name, -1);
+      
+      gkm_keyring_editor_set_keyring_name (GKM_KEYRING_EDITOR (self->priv->editor),
+					   keyring_name);
+    }
+}
+
+
 /* End of keyrings treeview functions */
 
 /* Key treeview functions */
@@ -1014,6 +1033,7 @@ gkm_main_ui_connect_glade_signals (GKMMainUI *self,
 {
   GtkWidget        *widget;
   GtkTreeSelection *selection;
+  GtkTreeModel     *model;
 
   g_signal_connect (G_OBJECT (self->priv->window),
 		    "destroy",
@@ -1063,6 +1083,12 @@ gkm_main_ui_connect_glade_signals (GKMMainUI *self,
 		    "changed",
 		    G_CALLBACK (on_keys_treeview_selection_changed), 
 		    self);
+
+  model = gtk_tree_view_get_model (GTK_TREE_VIEW (self->priv->keyrings_treeview));
+  g_signal_connect (G_OBJECT (model),
+		    "row-changed",
+		    G_CALLBACK (on_keyrings_model_row_changed), 
+		    self);
 }
 
 /* Normal items */
